@@ -1,3 +1,4 @@
+import json
 import os
 import sys
 import platform
@@ -9,7 +10,7 @@ from .account import Account
 from .user import User
 from .token import Token
 
-__version__ = "1.1.10"
+__version__ = "1.1.11"
 
 
 class FreedomClient(object):
@@ -56,13 +57,18 @@ class FreedomClient(object):
             return None
         return Account(account_data["account"], account_data, api=self.api)
 
-    def get_accounts(self, params=None, api_call_kwargs={}):
+    def get_accounts(self, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`Account`: Fetch a list of all accounts that are visible/accessible.
 
         Args:
             params (dict): Optional query parameters.
+            attributes (list): Optional list of attributes to return.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
+        if params is None:
+            params = {}
+        if attributes is not None:
+            params["attributes"] = json.dumps(attributes)
 
         result = self.api.call("GET", "/accounts", params=params, **api_call_kwargs)
         if not result:
@@ -72,13 +78,18 @@ class FreedomClient(object):
             for account_data in result
         ]
 
-    def get_users(self, params=None, api_call_kwargs={}):
+    def get_users(self, attributes=None, params=None, api_call_kwargs={}):
         """:obj:`list` of :obj:`User`: Fetch a list of all users that are visible/accessible.
 
         Args:
             params (dict): Optional query parameters.
+            attributes (list): Optional list of attributes to return.
             api_call_kwargs (dict): Optional keyword arguments for api call.
         """
+        if params is None:
+            params = {}
+        if attributes is not None:
+            params["attributes"] = json.dumps(attributes)
 
         result = self.api.call("GET", "/users", params=params, **api_call_kwargs)
         if not result:
