@@ -16,6 +16,10 @@ class Device(Entity):
     def url_base(self):
         return '/accounts/{}/devices'.format(self.account)
 
+    @property
+    def url_id(self):
+        return '{}/{}'.format(self.url_base, self._id)
+
     def command(self, topic=None, topic_type=None, data=None, expiration_secs=10, platform="ros"):
         cmd = {
             "topic": topic,
